import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, scaleBand, scaleLinear, max, format } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const margin = { top: 20, right: 30, bottom: 150, left: 220 };
const yAxisLabelOffset = 50;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  
  const yValue = d => d.Population;
  const xValue = d => d.Country;
  console.log(0);
 // const yValue = d => d.Country;
 // const xValue = d => d.Population;

  const siFormat = format('.2s');
  const yAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');

  const xScale = scaleBand()
    .domain(data.map(xValue))
    .range([0,innerWidth])
    .paddingInner(.1);

  const yScale = scaleLinear()
  .domain([0, max(data, yValue)])
    .range([0,innerHeight]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
          tickFormat={yAxisTickFormat}
        />
         <text
          className="axis-label"
        x={-100}
       y={innerHeight/2}
      textAnchor="middle"
      transform={`rotate(-90 ${-100} ${innerHeight/2})`}
        >
       Population
      </text>
        <AxisBottom xScale={xScale}  innerHeight={innerHeight}/>
      // 
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={yAxisTickFormat}
          innerHeight={innerHeight}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
